@@ -11,6 +11,7 @@
 #    under the License.
 
 import abc
+import multiprocessing
 import os
 import sys
 
@@ -34,14 +35,20 @@ class BuildTest(object):
         super(BuildTest, self).setUp()
         self.useFixture(log_fixture.SetLogLevel([__name__],
                                                 logging.logging.INFO))
-        self.build_args = [__name__, "--debug", '--threads', '4']
+
+        self.threads = multiprocessing.cpu_count()
+        if self.threads < 4:
+            self.threads = 4
+
+        self.build_args = [__name__, "--debug", '--threads', str(self.threads)]
 
     @testtools.skipUnless(os.environ.get('DOCKER_BUILD_TEST'),
                           'Skip the docker build test')
     def runTest(self):
         with patch.object(sys, 'argv', self.build_args):
             LOG.info("Running with args %s", self.build_args)
-            bad_results, good_results, unmatched_results = build.run_build()
+            (bad_results, good_results, unmatched_results,
+             skipped_results) = build.run_build()
 
         failures = 0
         for image, result in bad_results.items():
@@ -67,18 +74,18 @@ class BuildTest(object):
 class BuildTestCentosBinary(BuildTest, base.BaseTestCase):
     excluded_images = [
         "bifrost-base",
-        "congress-base",
+        "blazar-base",
+        "dragonflow-base",
         "freezer-base",
         "kafka",
         "karbor-base",
         "kuryr-base",
-        "manila-data",
         "monasca-base",
-        "neutron-sfc-agent",
+        "neutron-bgp-dragent",
+        "ovsdpdk",
         "searchlight-base",
         "senlin-base",
         "solum-base",
-        "tacker",
         "vitrage-base",
         "vmtp",
         "zun-base",
@@ -92,8 +99,9 @@ class BuildTestCentosBinary(BuildTest, base.BaseTestCase):
 
 class BuildTestCentosSource(BuildTest, base.BaseTestCase):
     excluded_images = [
+        "bifrost-base",
         "kafka",
-        "mistral-base",
+        "ovsdpdk",
     ]
 
     def setUp(self):
@@ -105,19 +113,23 @@ class BuildTestCentosSource(BuildTest, base.BaseTestCase):
 class BuildTestUbuntuBinary(BuildTest, base.BaseTestCase):
     excluded_images = [
         "bifrost-base",
+        "blazar-base",
         "cloudkitty-base",
         "congress-base",
+        "dragonflow-base",
+        "ec2-api",
         "freezer-base",
+        "heat-all",
         "karbor-base",
         "kuryr-base",
+        "mistral-event-engine",
         "monasca-base",
-        "neutron-sfc-agent",
+        "novajoin-base",
         "octavia-base",
-        "panko-base",
         "searchlight-base",
         "senlin-base",
         "solum-base",
-        "tacker",
+        "tacker-base",
         "vitrage-base",
         "vmtp",
         "zaqar",
@@ -131,7 +143,9 @@ class BuildTestUbuntuBinary(BuildTest, base.BaseTestCase):
 
 
 class BuildTestUbuntuSource(BuildTest, base.BaseTestCase):
-    excluded_images = []
+    excluded_images = [
+        "bifrost-base",
+    ]
 
     def setUp(self):
         super(BuildTestUbuntuSource, self).setUp()
@@ -139,21 +153,66 @@ class BuildTestUbuntuSource(BuildTest, base.BaseTestCase):
                                 "--type", "source"])
 
 
+class BuildTestDebianBinary(BuildTest, base.BaseTestCase):
+    excluded_images = [
+        "bifrost-base",
+        "blazar-base",
+        "cloudkitty-base",
+        "congress-base",
+        "dragonflow-base",
+        "ec2-api",
+        "freezer-base",
+        "heat-all",
+        "karbor-base",
+        "kuryr-base",
+        "mistral-event-engine",
+        "monasca-base",
+        "novajoin-base",
+        "octavia-base",
+        "searchlight-base",
+        "senlin-base",
+        "sensu-base",
+        "solum-base",
+        "tacker-base",
+        "vitrage-base",
+        "vmtp",
+        "zaqar",
+        "zun-base"
+    ]
+
+    def setUp(self):
+        super(BuildTestDebianBinary, self).setUp()
+        self.build_args.extend(["--base", "debian",
+                                "--type", "binary"])
+
+
+class BuildTestDebianSource(BuildTest, base.BaseTestCase):
+    excluded_images = [
+        "bifrost-base",
+        "sensu-base",
+    ]
+
+    def setUp(self):
+        super(BuildTestDebianSource, self).setUp()
+        self.build_args.extend(["--base", "debian",
+                                "--type", "source"])
+
+
 class BuildTestOracleLinuxBinary(BuildTest, base.BaseTestCase):
     excluded_images = [
         "bifrost-base",
-        "congress-base",
+        "blazar-base",
+        "dragonflow-base",
         "freezer-base",
         "kafka",
         "karbor-base",
         "kuryr-base",
-        "manila-data",
         "monasca-base",
-        "neutron-sfc-agent",
+        "neutron-bgp-dragent",
+        "ovsdpdk",
         "searchlight-base",
         "senlin-base",
         "solum-base",
-        "tacker",
         "vitrage-base",
         "vmtp",
         "zun-base",
@@ -167,7 +226,9 @@ class BuildTestOracleLinuxBinary(BuildTest, base.BaseTestCase):
 
 class BuildTestOracleLinuxSource(BuildTest, base.BaseTestCase):
     excluded_images = [
+        "bifrost-base",
         "kafka",
+        "ovsdpdk",
     ]
 
     def setUp(self):
